Documentation
¶
Overview ¶
Package finding defines the Finding type produced by mem-guard heuristics along with severity levels and human/JSON printers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Finding ¶
type Finding struct {
Heuristic string `json:"heuristic"`
Severity Severity `json:"severity"`
Position token.Position `json:"position"`
Message string `json:"message"`
LoopKind string `json:"loop_kind,omitempty"`
FuncName string `json:"func_name"`
Details string `json:"details,omitempty"`
}
Finding represents a single analysis result.
type Severity ¶
type Severity int
Severity indicates confidence that a finding is a real issue.
func (Severity) MarshalJSON ¶
Click to show internal directories.
Click to hide internal directories.